@@ -142,12 +142,14 @@ class Archiver(
         id: builtins.str,
         *,
         backup_configurations: typing.Sequence[typing.Union["BackupConfiguration", typing.Dict[builtins.str, typing.Any]]],
+        notification_events: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.EventType]] = None,
         retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param backup_configurations: (experimental) Contains details on the git repositories to be backed up.
+        :param notification_events: (experimental) S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
         :param retention_days: (experimental) Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
 
         :stability: experimental
@@ -157,7 +159,9 @@ class Archiver(
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ArchiverProperties(
-            backup_configurations=backup_configurations, retention_days=retention_days
+            backup_configurations=backup_configurations,
+            notification_events=notification_events,
+            retention_days=retention_days,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -180,6 +184,24 @@ class Archiver(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "bucket", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="kmsKey")
+    def kms_key(self) -> _aws_cdk_aws_kms_ceddda9d.Key:
+        '''(experimental) The KMS key used to encrypt the logs and the SNS topic.
+
+        :stability: experimental
+        :memberof: Archiver
+        :type: {kms.Key}
+        '''
+        return typing.cast(_aws_cdk_aws_kms_ceddda9d.Key, jsii.get(self, "kmsKey"))
+
+    @kms_key.setter
+    def kms_key(self, value: _aws_cdk_aws_kms_ceddda9d.Key) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8c36f29d0f7853cd545faec426b34c1244d318c139f2dffe55decab75b8bed45)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "kmsKey", value)
+
     @builtins.property
     @jsii.member(jsii_name="logGroup")
     def log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
@@ -198,24 +220,6 @@ class Archiver(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "logGroup", value)
 
-    @builtins.property
-    @jsii.member(jsii_name="logGroupKmsKey")
-    def log_group_kms_key(self) -> _aws_cdk_aws_kms_ceddda9d.Key:
-        '''(experimental) The KMS key used to encrypt the logs.
-
-        :stability: experimental
-        :memberof: Archiver
-        :type: {kms.Key}
-        '''
-        return typing.cast(_aws_cdk_aws_kms_ceddda9d.Key, jsii.get(self, "logGroupKmsKey"))
-
-    @log_group_kms_key.setter
-    def log_group_kms_key(self, value: _aws_cdk_aws_kms_ceddda9d.Key) -> None:
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__73a45d354e5f9a04dc155598cdf7614bfc4521dbdff7f8efd525a8166ff14705)
-            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        jsii.set(self, "logGroupKmsKey", value)
-
     @builtins.property
     @jsii.member(jsii_name="props")
     def props(self) -> "ArchiverProperties":
@@ -255,6 +259,7 @@ class Archiver(
     jsii_struct_bases=[],
     name_mapping={
         "backup_configurations": "backupConfigurations",
+        "notification_events": "notificationEvents",
         "retention_days": "retentionDays",
     },
 )
@@ -263,10 +268,12 @@ class ArchiverProperties:
         self,
         *,
         backup_configurations: typing.Sequence[typing.Union["BackupConfiguration", typing.Dict[builtins.str, typing.Any]]],
+        notification_events: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.EventType]] = None,
         retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ) -> None:
         '''
         :param backup_configurations: (experimental) Contains details on the git repositories to be backed up.
+        :param notification_events: (experimental) S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
         :param retention_days: (experimental) Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
 
         :stability: experimental
@@ -274,10 +281,13 @@ class ArchiverProperties:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__bfaace2f4df93a4fab67f960625a0f4057a1c4ba23833a63c0ffee999a9a724d)
             check_type(argname="argument backup_configurations", value=backup_configurations, expected_type=type_hints["backup_configurations"])
+            check_type(argname="argument notification_events", value=notification_events, expected_type=type_hints["notification_events"])
             check_type(argname="argument retention_days", value=retention_days, expected_type=type_hints["retention_days"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "backup_configurations": backup_configurations,
         }
+        if notification_events is not None:
+            self._values["notification_events"] = notification_events
         if retention_days is not None:
             self._values["retention_days"] = retention_days
 
@@ -293,6 +303,22 @@ class ArchiverProperties:
         assert result is not None, "Required property 'backup_configurations' is missing"
         return typing.cast(typing.List["BackupConfiguration"], result)
 
+    @builtins.property
+    def notification_events(
+        self,
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.EventType]]:
+        '''(experimental) S3 events that will trigger a message to the SNS topic.
+
+        For example
+        "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
+
+        :stability: experimental
+        :memberof: ArchiverProperties
+        :type: {s3.EventType[]}
+        '''
+        result = self._values.get("notification_events")
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.EventType]], result)
+
     @builtins.property
     def retention_days(
         self,
@@ -433,6 +459,7 @@ def _typecheckingstub__59b1d445ea6a4ea2b344c5e83eb14b7e5d57e243d55dbad607605e1e2
     id: builtins.str,
     *,
     backup_configurations: typing.Sequence[typing.Union[BackupConfiguration, typing.Dict[builtins.str, typing.Any]]],
+    notification_events: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.EventType]] = None,
     retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
 ) -> None:
     """Type checking stubs"""
@@ -444,14 +471,14 @@ def _typecheckingstub__a6323f8f3cdbd2b11e534f545ef6432e903b1c3129b74f986595de806
     """Type checking stubs"""
     pass
 
-def _typecheckingstub__9bb1a921963ed134fd11e5243da72c17693bf46b95bcb2787c98f86c2344cac1(
-    value: _aws_cdk_aws_logs_ceddda9d.LogGroup,
+def _typecheckingstub__8c36f29d0f7853cd545faec426b34c1244d318c139f2dffe55decab75b8bed45(
+    value: _aws_cdk_aws_kms_ceddda9d.Key,
 ) -> None:
     """Type checking stubs"""
     pass
 
-def _typecheckingstub__73a45d354e5f9a04dc155598cdf7614bfc4521dbdff7f8efd525a8166ff14705(
-    value: _aws_cdk_aws_kms_ceddda9d.Key,
+def _typecheckingstub__9bb1a921963ed134fd11e5243da72c17693bf46b95bcb2787c98f86c2344cac1(
+    value: _aws_cdk_aws_logs_ceddda9d.LogGroup,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -471,6 +498,7 @@ def _typecheckingstub__9dd4ea8c9e2284178c61c09574e728813a93f8d586a9e4839a680d1ed
 def _typecheckingstub__bfaace2f4df93a4fab67f960625a0f4057a1c4ba23833a63c0ffee999a9a724d(
     *,
     backup_configurations: typing.Sequence[typing.Union[BackupConfiguration, typing.Dict[builtins.str, typing.Any]]],
+    notification_events: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.EventType]] = None,
     retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
 ) -> None:
     """Type checking stubs"""
